==> yos.core-2.3.0-sources.jar: common/UserInfo.java <==
package common;

public class UserInfo {
    private long userid;
    private String username;
    private String phonenumber;
    private String siteid;
    private long usersiteid;
    private int usertype;
    public Controller controller;

    public UserInfo(Controller controller) {
        this.controller = controller;
    }

    public long getUserId() {
        return userid;
    }

    public void setUserId(long userid) {
        this.userid = userid;
    }

    public String getUserName() {
        return username;
    }

    public void setUserName(String username) {
        this.username = username;
    }

    public String getPhoneNumber() {
        return phonenumber;
    }

    public void setPhoneNumber(String phonenumber) {
        this.phonenumber = phonenumber;
    }

    public String getSiteId() {
        return siteid;
    }

    public void setSiteId(String siteid) {
        this.siteid = siteid;
    }

    public long getUserSiteId() {
        return usersiteid;
    }

    public void setUserSiteId(long usersiteid) {
        this.usersiteid = usersiteid;
    }

    public int getUserType() {
        return usertype;
    }

    public void setUserType(int usertype) {
        this.usertype = usertype;
    }

    public boolean isSysAdministrator() throws YosException {
        return controller.dbConnect.runSqlQuery("select * from sys_users where userid='" + getUserId() + "' and sysadministrator=1").isNotEmpty();
    }

    public boolean isSiteAdministrator() throws YosException {
        return getUserType() == 0;
    }
}

==> yos.core-2.3.1-sources.jar: common/UserInfo.java <==
package common;

import beans.department.Department;
import beans.user.User;

import java.util.ArrayList;

public class UserInfo {
    private long userid;
    private String username;
    private String phonenumber;
    private String siteid;
    private long usersiteid;
    private int usertype;
    public Controller controller;

    public UserInfo(Controller controller) {
        this.controller = controller;
    }

    public long getUserId() {
        return userid;
    }

    public void setUserId(long userid) {
        this.userid = userid;
    }

    public String getUserName() {
        return username;
    }

    public void setUserName(String username) {
        this.username = username;
    }

    public String getPhoneNumber() {
        return phonenumber;
    }

    public void setPhoneNumber(String phonenumber) {
        this.phonenumber = phonenumber;
    }

    public String getSiteId() {
        return siteid;
    }

    public void setSiteId(String siteid) {
        this.siteid = siteid;
    }

    public long getUserSiteId() {
        return usersiteid;
    }

    public void setUserSiteId(long usersiteid) {
        this.usersiteid = usersiteid;
    }

    public int getUserType() {
        return usertype;
    }

    public void setUserType(int usertype) {
        this.usertype = usertype;
    }

    public boolean isSysAdministrator() throws YosException {
        return controller.dbConnect.runSqlQuery("select * from sys_users where userid='" + getUserId() + "' and sysadministrator=1").isNotEmpty();
    }

    public boolean isSiteAdministrator() throws YosException {
        return getUserType() == 0;
    }

    public ArrayList<Long> getSubUserIds(Controller controller) throws YosException {
        return User.getSubUserIds(controller);
    }

    public ArrayList<Long> getSubHrIds(Controller controller) throws YosException {
        return User.getSubHrIds(controller);
    }

    public ArrayList<Long> getSubEnterpriseids(Controller controller) throws YosException {
        return User.getSubEnterpriseids(controller);
    }

    public ArrayList<Long> getSubDepartmentIds(Controller controller) throws YosException {
        return Department.getSubDepartmentIds(controller);
    }
}
